@@ -442,19 +442,27 @@ class KubernetesPodExecutor(TaskExecutor):
                 privileged=task_config.privileged,
             )
 
+        requests = {
+            "cpu": task_config.cpus_request if task_config.cpus_request else None,
+            "memory": f"{task_config.memory_request}Mi" if task_config.memory_request else None,
+        }
+        limits = {
+            "cpu": task_config.cpus,
+            "memory": f"{task_config.memory}Mi",
+            "ephemeral-storage": f"{task_config.disk}Mi",
+        }
+        resources = V1ResourceRequirements(
+            limits=limits,
+            requests=requests,
+        )
+
         return V1Container(
             image=task_config.image,
             name=name,
             command=["/bin/sh", "-c"],
             args=[task_config.command],
             security_context=security_context,
-            resources=V1ResourceRequirements(
-                limits={
-                    "cpu": task_config.cpus,
-                    "memory": f"{task_config.memory}Mi",
-                    "ephemeral-storage": f"{task_config.disk}Mi",
-                }
-            ),
+            resources=resources,
             env=get_kubernetes_env_vars(
                 environment=task_config.environment,
                 secret_environment=task_config.secret_environment,
@@ -462,6 +470,9 @@ class KubernetesPodExecutor(TaskExecutor):
             ),
             volume_mounts=volume_mounts,
             ports=[V1ContainerPort(container_port=port) for port in task_config.ports],
+            stdin=task_config.stdin,
+            stdin_once=task_config.stdin_once,
+            tty=task_config.tty,
         )
 
     def run(self, task_config: KubernetesTaskConfig) -> Optional[str]:
